smart_state_handler library
Classes
- OverlayStateConfig
- Configuration for individual overlay state appearance
- SmartStateAnimationConfig
- Animation configuration for state transitions
-
SmartStateCache<
K, V> - A simple LRU (Least Recently Used) cache for state management
-
SmartStateHandler<
T> - A comprehensive state management widget that handles all common UI states with enhanced developer experience and flexible customization options.
- SmartStateKeepAlive
- A widget that prevents rebuilds if the child hasn't changed
- SmartStateOverlayConfig
- Configuration class for overlay state customization
- SmartStateSnackbarConfig
- Configuration class for snackbar customization
- SmartStateTextConfig
- Configuration class for customizing text content
- SmartStateWidgetConfig
- Configuration class for customizing widget content
- SnackbarStateConfig
- Configuration for individual snackbar state appearance
Enums
- SmartState
- Enum representing all possible states
- SmartStateTransitionType
- Types of transitions between states
- SnackbarPosition
- Snackbar position on screen
- SnackbarType
- Snackbar type for different states
Mixins
- SmartStateMemoization
- Mixin to provide memoization capabilities for widgets Helps prevent unnecessary rebuilds
Extensions
- SmartStateExtension on SmartState
- Extension methods for SmartState enum for convenient state checking